<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;

class HomeController extends Controller
{
    public function index() {
        return view('index');
    }

    public function dashboard() {
        return view('dashboard');
    }

    public function showLoginForm() {
    return view('login'); // or 'auth.login' depending on your folder
    }

    public function loginProcess(Request $request) {
        $request->validate([
            'email' => 'required|email',
            'password' => 'required',
            'role'  => 'required',
        ]);

        $credentials = $request->only('email', 'password');

        if (Auth::attempt($credentials)) {
            return redirect()->route('dashboard');
        }

        return back()->withErrors(['email' => 'Invalid credentials'])->withInput();
    }

    public function showRegisterForm() {
        return view('auth.register');
    }

    public function register(Request $request)
{
    $request->validate([
        'name' => 'required|string|max:255',
        'email' => 'required|string|email|max:255|unique:users',
        'password' => 'required|string|min:6|confirmed',
        'role' => 'required|string'
    ]);

    try {
        User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => Hash::make($request->password),
            'role' => $request->role
        ]);
    } catch (\Exception $e) {
        dd($e->getMessage());
    }

    return redirect()->route('login')->with('success', 'Registration successful.');
}

    public function logout()
    {
    \Illuminate\Support\Facades\Auth::logout();
    return redirect()->route('login')->with('success', 'You have been logged out.');
    }
}
